@@ -25,7 +25,7 @@ from thunder.quartznet.compatibility import (
 )
 from thunder.quartznet.transform import FilterbankFeatures
 from thunder.text_processing.transform import BatchTextTransformer
-from thunder.text_processing.vocab import Vocab
+from thunder.text_processing.vocab import SimpleVocab, Vocab
 
 
 class QuartznetModule(pl.LightningModule):
@@ -49,7 +49,7 @@ class QuartznetModule(pl.LightningModule):
         feature creation and text processing.
 
         Args:
-            initial_vocab_tokens : List of tokens to be used in the vocab, special tokens should not be included here.
+            initial_vocab_tokens : List of tokens to be used in the vocab, special tokens should not be included here. Check [`docs`](https://scart97.github.io/thunder-speech/quick%20reference%20guide/#how-to-get-the-initial_vocab_tokens-from-my-dataset)
             sample_rate : Check [`FilterbankFeatures`][thunder.quartznet.transform.FilterbankFeatures]
             n_window_size : Check [`FilterbankFeatures`][thunder.quartznet.transform.FilterbankFeatures]
             n_window_stride : Check [`FilterbankFeatures`][thunder.quartznet.transform.FilterbankFeatures]
@@ -89,7 +89,7 @@ class QuartznetModule(pl.LightningModule):
         # Example input is one second of fake audio
         self.example_input_array = (
             torch.randn((10, sample_rate)),
-            torch.randint(10, sample_rate, (10,)),
+            torch.randint(10, sample_rate, (10,)) / sample_rate,
         )
 
     def build_text_transform(
@@ -104,7 +104,11 @@ class QuartznetModule(pl.LightningModule):
         Returns:
             The transform that will both `encode` the text and `decode_prediction`.
         """
-        vocab = Vocab(initial_vocab_tokens, nemo_compat=nemo_compat_vocab)
+        vocab = (
+            SimpleVocab(initial_vocab_tokens)
+            if nemo_compat_vocab
+            else Vocab(initial_vocab_tokens)
+        )
         return BatchTextTransformer(vocab=vocab)
 
     def build_decoder(self, decoder_input_channels: int, vocab_size: int) -> nn.Module:
